P8Hub
Description: Host your own Generative AI Services.

# Private AI Hub

Host and use your own Generative AI Services. Keep everything private.

### Number of Services

4

Managed by P8Hub

### CPU

86%

Number of cores: 4

### Memory

1.2GB / 32GB

Percentage: 3.75%

### Number of GPUs

1

Average utilization: 20%

## Running Services

### Ollama LLM

Chat with local llamas - running

running
Created April 2023

### PrivateGPT

Ask your documents questions - running

running
Created April 2023

### Stable Duffusion WebUI

Generate images from text - running

running
Created April 2023

### LocalPilot

Code with AI assistance - running

running
Created April 2023

## Deploy New Services

### Ollama LLM

Chat with local llamas

### PrivateGPT

Ask your documents questions

### Stable Duffusion WebUI

Generate images from text

### LocalPilot

Code with AI assistance